@@ -6,7 +6,6 @@
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE PatternGuards #-}
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE EmptyDataDecls #-}
 module Text.Internal.Css where
@@ -71,9 +70,6 @@ instance Semigroup Mixin where
     Mixin a x <> Mixin b y = Mixin (a ++ b) (x ++ y)
 instance Monoid Mixin where
     mempty = Mixin mempty mempty
-#if !(MIN_VERSION_base(4,11,0))
-    mappend = (<>)
-#endif
 
 data TopLevel a where
     TopBlock   :: !(Block a) -> TopLevel a
@@ -108,9 +104,6 @@ data CDData url = CDPlain Builder
 
 pack :: String -> Text
 pack = T.pack
-#if !MIN_VERSION_text(0, 11, 2)
-{-# NOINLINE pack #-}
-#endif
 
 fromText :: Text -> Builder
 fromText = TLB.fromText
@@ -172,7 +165,7 @@ cssFileDebug :: Bool -- ^ perform the indent-to-brace conversion
              -> FilePath
              -> Q Exp
 cssFileDebug toi2b parseBlocks' parseBlocks fp = do
-    s <- fmap TL.unpack $ qRunIO $ readUtf8File fp
+    s <- readFileQ fp
     let vs = cssUsedIdentifiers toi2b parseBlocks s
     c <- mapM vtToExp vs
     cr <- [|cssRuntime toi2b|]
@@ -259,7 +252,7 @@ cssRuntime :: Bool -- ^ i2b?
            -> (url -> [(Text, Text)] -> Text)
            -> Css
 cssRuntime toi2b parseBlocks fp cd render' = unsafePerformIO $ do
-    s' <- fmap TL.unpack $ qRunIO $ readUtf8File fp
+    s' <- readUtf8FileString fp
     let s = if toi2b then i2b s' else s'
     let a = either (error . show) id $ parse parseBlocks s s
     return $ CssWhitespace $ goTop [] a
